<?php
/*
Plugin Name: Promotion Slider
Plugin URI: http://www.orderofbusiness.net/plugins/promotion-slider/
Description: This plugin creates a special post type called 'Promotions' that it uses to populate the carousel.  Just use the shortcode [promoslider] to display the slider on your site.  Be sure to check the <a href="http://wordpress.org/extend/plugins/promotion-slider/faq/" target="_blank">user guide</a> for more information on what this plugin can really do!
Version: 3.0.1
Author: Micah Wood
Author URI: http://www.orderofbusiness.net/micah-wood/
License: GPL2

Copyright 2010  Micah Wood  (email : micah.wood@orderofbusiness.net)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if( !defined('PROMOSLIDER_VER') ) define( 'PROMOSLIDER_VER', '3.0.1' );
if( !defined('PROMOSLIDER_PATH') ) define( 'PROMOSLIDER_PATH', dirname(__FILE__) );
if( !defined('PROMOSLIDER_URL') ) define( 'PROMOSLIDER_URL', get_bloginfo('wpurl').'/wp-content/plugins/promotion-slider' );

if( !class_exists('promo_slider') ){
  class promo_slider{
	  
	  // Define post type and taxonomy name
	  private $post_type = 'promotion';
	  private $taxonomy_name = 'promotion-categories';
	  private $default_time_delay = 6;
	  
	  function __construct(){
		  
		  // Create the post type that we will pull from
		  include('includes/SD_Register_Post_Type.php');
		  $args = array('register_meta_box_cb' => array(&$this, 'meta_box') );
		  new SD_Register_Post_Type($this->post_type, $args);
		  
		  // Flush rewrite rules once after adding new post type
		  register_activation_hook( __FILE__, array(&$this, 'activate') );
		  
		  // Initiate key components
		  add_action( 'init', array(&$this, 'init') );
		  add_action( 'admin_menu', array(&$this, 'admin_menu') );
		  
		  // Add theme support for post thumbnails
		  add_theme_support( 'post-thumbnails' );

	  }
	  
	  function init(){
		  
		  // Register and load our jquery and css files if we are on the front end of the site
		  if( !is_admin() ) {
			  wp_enqueue_script( 'promoslider_main', PROMOSLIDER_URL.'/includes/promo_slider.js', array('jquery'), FALSE, TRUE );
			  wp_enqueue_style( 'promoslider_main', PROMOSLIDER_URL.'/css/slide.css' );
		  }
		  
		  // Localize plugin options
			// Set Time Delay
			if( !$time_delay = get_option('time_delay') ) $time_delay = $this->default_time_delay;
			// Set Auto Advance
			$auto_advance = get_option('auto_advance');
			if( $auto_advance != true ) $auto_advance = false;
			// Output data
			$data = array( 'timeDelay' => $time_delay, 'autoAdvance' => $auto_advance, 'version' => PROMOSLIDER_VER );
			wp_localize_script('promoslider_main', 'promo_slider_options', $data);
		  
		  // Create [promoslider] shortcode
		  add_shortcode( 'promoslider', array(&$this, 'show') );
		  
		  // Enable use of the shortcode in text widgets
		  add_filter('widget_text', 'do_shortcode');
		  
		  // Save meta data when saving promotions
		  add_action( 'save_post', array(&$this, 'save_meta_data') );
		  
		  // Register taxonomy for promotions
		  register_taxonomy( $this->taxonomy_name, array($this->post_type), array(
			  'hierarchical' => true,
			  'labels' => array( 'name' => __('Categories'),
								'singular_name' => __('Category'),
								'search_items' => __('Search Categories'),
								'all_items' => __('All Categories'),
								'parent_item' => __('Parent Category'),
								'parent_item_colon' => __('Parent Category:'),
								'edit_item' => __('Edit Category'),
								'update_item' => __('Update Category'),
								'add_new_item' => __('Add New Category') ),
			  'show_ui' => true,
			  'query_var' => true,
			  'rewrite' => array( 'slug' => 'promotions' )
		  ));
	  }
	  
	  function admin_menu(){
		// Create options page
		add_submenu_page( 'edit.php?post_type=promotion', __('Promotion Slider Options'), __('Slider Options'), 'manage_options', 'options', array(&$this, 'options_page') );
		// Register settings using our function
		add_action( 'admin_init', array(&$this, 'register_settings') );
	  }
	  
	  function register_settings(){
		// Register plugin options
		register_setting( 'promoslider-settings-group', 'time_delay' );
		register_setting( 'promoslider-settings-group', 'auto_advance' );
		register_setting( 'promoslider-settings-group', 'show_title' );
		register_setting( 'promoslider-settings-group', 'show_excerpt' );
		register_setting( 'promoslider-settings-group', 'nav_option' );
		register_setting( 'promoslider-settings-group', 'disable_fancy_title' );
		register_setting( 'promoslider-settings-group', 'disable_fancy_nav' );
	  }
	  
	  function options_page(){ ?>
        <div class="wrap">
          <h2><?php _e('Promotion Slider Options'); ?></h2>
          
          <p><?php _e('The options below will change the settings for all of the Promotion Sliders running on your website.  For more granular control, please <a href="http://wordpress.org/extend/plugins/promotion-slider/faq/" target="_blank">read our documentation</a>.'); ?></p>
          
          <form method="post" action="options.php">
              
			  <?php 
				settings_fields( 'promoslider-settings-group' ); 
				
				// Get time delay
				if( !$time_delay = get_option('time_delay') ) $time_delay = $this->default_time_delay;
				// Get auto advance
				$auto_advance = get_option('auto_advance');
				if( $auto_advance != true ) $auto_advance = false;
			  ?>
              
              <table class="form-table">
                <tr valign="top">
                  <th scope="row"><?php _e('Set Slider Time Delay'); ?></th>
                  <td>
                    <select name="time_delay">
                      <?php for($i=3; $i<=15; $i++): ?>
                        <option value="<?php echo $i; ?>"<?php if( $time_delay == $i ) echo 'selected="selected"'; ?>><?php echo $i; ?> <?php _e('Seconds'); ?></option>
                      <?php endfor; ?>
                    </select>
                  </td>
                </tr>
                 
                <tr valign="top">
                  <th scope="row"><?php _e('Automatic Slide Advancement'); ?></th>
                  <td>
                    <input type="checkbox" name="auto_advance" value="true" <?php if( $auto_advance ) echo 'checked="checked"'; ?> /> 
                    <?php _e('Check to enable'); ?>
                  </td>
                </tr>
                
                <tr valign="top">
                  <th scope="row"><?php _e('Promotion Title Display'); ?></th>
                  <td>
                    <input type="checkbox" name="show_title" value="true" <?php if( get_option('show_title') == true ) echo 'checked="checked"'; ?> /> 
                    <?php _e('Check to enable'); ?>
                  </td>
                </tr>
                
                <tr valign="top">
                  <th scope="row"><?php _e('Display Fancy Title'); ?></th>
                  <td>
                    <input type="checkbox" name="disable_fancy_title" value="true" <?php if( get_option('disable_fancy_title') == true ) echo 'checked="checked"'; ?> /> 
                    <?php _e('Check to disable'); ?>
                  </td>
                </tr>
                
                <tr valign="top">
                  <th scope="row"><?php _e('Promotion Excerpt Display'); ?></th>
                  <td>
                    <input type="checkbox" name="show_excerpt" value="true" <?php if( get_option('show_excerpt') == true ) echo 'checked="checked"'; ?> /> 
                    <?php _e('Check to enable'); ?>
                  </td>
                </tr>
                
                <tr valign="top">
                  <th scope="row"><?php _e('Slider Navigation Display'); ?></th>
                  <td>
                    <input type="radio" name="nav_option" value="default" <?php if( !get_option('nav_option') || get_option('nav_option') == 'default' ) echo 'checked="checked"'; ?> />
                    <?php _e('Default Slider Navigation'); ?><br />
                    <input type="radio" name="nav_option" value="links" <?php if( get_option('nav_option') == 'links' ) echo 'checked="checked"'; ?> />
                    <?php _e('Slider Navigation Links'); ?><br />
                    <input type="radio" name="nav_option" value="none" <?php if( get_option('nav_option') == 'none' ) echo 'checked="checked"'; ?> />
                    <?php _e('No Slider Navigation'); ?><br />
                  </td>
                </tr>
                
                <tr valign="top">
                  <th scope="row"><?php _e('Display Fancy Default Nav'); ?></th>
                  <td>
                    <input type="checkbox" name="disable_fancy_nav" value="true" <?php if( get_option('disable_fancy_nav') == true ) echo 'checked="checked"'; ?> /> 
                    <?php _e('Check to disable'); ?>
                  </td>
                </tr>
              </table>
              
              <p class="submit">
                <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
              </p>
          
          </form>
        </div>
		
		<style type="text/css">
		  #support{border:1px solid #000; padding:5px 10px 10px 10px; width:500px; margin-top:50px;}
		  #support li{list-style-type:disc; margin-left:25px;}
        </style>
        
        <div id="support" class="wrap">
          <h3><?php _e('Support This Plugin'); ?></h3>
          <p><?php _e('If you have found this plugin helpful, please consider:');?>
            <ul>
              <li><?php _e('Linking to our site:');?> <a href="http://www.orderofbusiness.net/" target="_blank">http://www.orderofbusiness.net/</a></li>
              <li><?php _e('Making a donation');?></li>
            </ul>
          </p>
          <form action="https://www.paypal.com/cgi-bin/webscr" method="post">
            <input type="hidden" name="cmd" value="_s-xclick">
            <input type="hidden" name="hosted_button_id" value="ZWYWE2TQLXBJY">
            <input type="image" src="https://www.paypal.com/en_US/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
            <img alt="" border="0" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="1" height="1">
          </form>
        </div><?php
	  }
	  
	  function show( $atts ){
		// Extract shortcode attributes and set defaults
		extract( shortcode_atts(array('id' => NULL, 
									  'post_type' => 'promotion', 
									  'category' => NULL, 
									  'width' => NULL, 
									  'height' => NULL, 
									  'time_delay' => NULL, 
									  'auto_advance' => NULL), $atts) );
		
		// Make $post global and save current value so we can restore it later
		global $post; 
		$tmp_post = $post;
		
		// Create an array with default values that we can use to build our query
		$query = array('numberposts' => -1, 'post_type' => $this->post_type);
		
		// Set the post type that we will be looking for.  If post type is invalid, use the default
		if( post_type_exists($post_type) ) $query['post_type'] = $post_type;
		
		// Check to see if the category is set and the term exists.  If it exists and the post type is post or the default, set the category based on taxonomy.
		if( !empty($category) && term_exists($category) ){
		  if( $query['post_type'] == $this->post_type ) $query[$this->taxonomy_name] = $category;
		  elseif( $query['post_type'] == 'post' ) $query['category'];
		}
		
		// Use the promoslider_query filter to customize the results returned.
		$query = apply_filters('promoslider_query', $query);
		// Use the promoslider_query_by_id filter to customize a query for a particular slider.
		$query = apply_filters('promoslider_query_by_id', array('query' => $query, 'id' => $id));
		
		// Run query and get posts
		$promo_posts = get_posts( $query );
		
		// If there are results, build slider.  Otherwise, don't show anything.
		if($promo_posts): $i = 1; ?>
        
        <?php 
		// Set width and height of slider if provided
		if($width || $height) $style = ' style="';
		if($width) $style .= 'width:'.$width.';';
		if($width && $height) $style .= ' ';
		if($height) $style .= 'height:'.$height.';';
		if($width || $height) $style .= '"';
		
		// Validate time delay
		$time_delay = (int) $time_delay;
		if( !is_int($time_delay) || $time_delay < 3 || $time_delay > 15 ) $time_delay = NULL;
		
		// Validate auto advance
		if($auto_advance !== NULL){
			$auto_advance = (string) strtolower($auto_advance);
			if($auto_advance == 'true') $auto_advance = ' auto_advance';
			elseif($auto_advance == 'false') $auto_advance = ' no_auto_advance';
			else $auto_advance = NULL;
		}
		
		// Begin Output
		ob_start();

		do_action('before_promoslider', $id); ?>
        
		<div <?php if(isset($id)) echo 'id="'.$id.'" '; ?>class="promo_slider<?php echo $auto_advance; ?>"<?php if($width || $height) echo $style; ?>>
        <?php if($time_delay) echo '<span class="promo_slider_time_delay" style="display:none;">'.$time_delay.'</span>'; ?>
		  
		  <?php foreach($promo_posts as $post): setup_postdata($post);
		    // Get the title
			$title = get_the_title(); 
			// Get the excerpt
			$excerpt = get_the_excerpt();
			// Get the thumbnail, if any
			if( function_exists('has_post_thumbnail') && has_post_thumbnail($post->ID) ) $thumb = get_the_post_thumbnail($post->ID, 'full');
			else $thumb = NULL;
			// If the destination url is set by the user, use that.  Otherwise, use the permalink
			if( !$dest_url = get_post_meta($post->ID, '_promo_slider_url', TRUE) ){ $dest_url = get_permalink($post->ID); }
			// If the target attribute is set the user, use that.  Otherwise, set it to _self
			if( !$target = get_post_meta($post->ID, '_promo_slider_target', TRUE) ){ $target = '_self'; } 
			// Store all the values in an array and pass it to the promoslider_content action
			$values = array('title' => $title, 'excerpt' => $excerpt, 'image' => $thumb, 'destination_url' => $dest_url, 'target' => $target, 'id' => $id, 'disable_links' => get_post_meta($post->ID, '_promo_slider_disable_links', TRUE)); ?>
						
			<div class="panel panel-<?php echo $i; ?>" value="<?php echo $i; ?>">
			  <?php // Use the promoslider_content action to populate the contents for panel
			  do_action('promoslider_content', $values); ?>
			</div>
			  
			<?php $i++; ?>
		  <?php endforeach; 
		  
		  // Restore original value of $post global variable for later use by WordPress
		  $post = $tmp_post; ?>
			  
		  <?php if($i > 2): ?>
			<?php // Use promoslider_nav action to generate the nav options
			do_action('promoslider_nav', $id); ?>
		  <?php endif; ?>
			
		  <div class="clear"></div>
			
		</div><?php 
		do_action('after_promoslider');
		
		// End Output
		$slider = ob_get_contents();
		ob_end_clean();
		
		return $slider;
		
		endif;
	  }
	  
	  function meta_box() {
		  // Add the meta box for promotions so users can customize the destination urls
		  add_meta_box( 'promo_slider_meta_box', __('Set Destination URL (Optional)'), array(&$this, 'meta_box_content'), $this->post_type );
	  }
	  
	  function meta_box_content() {
		  global $post;
		  
		  // Use nonce for verification
		  wp_nonce_field( 'ps_update_promotion', 'promo_slider_noncename' ); 
		  
		  // The actual fields for data entry  ?>
		  <p><?php _e('If you would like to have the link in the slider point somewhere besides this promotion, enter the desired URL here:'); ?></p>
		  <!-- Destination URL -->
          <p><label for="_promo_slider_url"><?php _e('Destination URL: ') ?></label> 
		  <input type="text" id= "_promo_slider_url" name="_promo_slider_url" value="<?php $value = get_post_meta($post->ID, '_promo_slider_url', TRUE); if(!empty($value)) echo $value; ?>" size="75" />
          </p>
		  <!-- Link Target Attribute -->
          <p><label for="_promo_slider_target"><?php _e('Select the behaviour for this link: ');?></label>
		  <?php $target = get_post_meta($post->ID, '_promo_slider_target', TRUE); $selected = ' selected="selected"'; ?>
		  <select name="_promo_slider_target">
			<option value=""<?php if( empty($target) ) echo $selected; ?>><?php _e('-- Choose One --'); ?></option>
			<option value="_self"<?php if( $target == '_self' ) echo $selected; ?>><?php _e('Open link in same page'); ?></option>
			<option value="_blank"<?php if( $target == '_blank' ) echo $selected; ?>><?php _e('Open link in a new page'); ?></option>
		  </select></p>
          <!-- Disable Links for this Promotion -->
          <p><label for="_promo_slider_url"><?php _e('Disable all links for this promotion: ') ?></label> 
		  <input type="checkbox" id= "_promo_slider_disable_links" name="_promo_slider_disable_links" value="true"<?php if( get_post_meta($post->ID, '_promo_slider_disable_links', TRUE) ) echo 'checked="checked"'; ?> size="75" /></p>
		  <?php
	  }
	  
	  function save_meta_data( $post_id ) {
  
		  // If this is an auto save, our form has not been submitted, so we don't want to do anything
		  if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) return $post_id;
		  
		  // Is the post type correct?
		  if ( isset($_POST['post_type']) && $this->post_type != $_POST['post_type'] ) return $post_id;
		  
		  // Verify this came from our screen and with proper authorization, because save_post can be triggered at other times
		  if ( !isset($_POST['promo_slider_noncename']) || !wp_verify_nonce( $_POST['promo_slider_noncename'], 'ps_update_promotion' )) { return $post_id; }
			
		  // Can user edit this post?
		  if ( !current_user_can('edit_post', $post_id) ) return $post_id;
		
		  // OK, we're authenticated - find and save the data		
		  $data = array('_promo_slider_url', '_promo_slider_target', '_promo_slider_disable_links');
		  
		  // Use this filter to add postmeta to save for the default post type
		  $data = apply_filters('promoslider_add_meta_to_save', $data);
		  
		  foreach($data as $meta){
			  // Get current meta
			  $current = get_post_meta($post_id, $meta, TRUE);
			  // Get new meta
			  $new = $_POST[$meta];
			  
			  // If the new meta is empty, delete the current meta
			  if( empty($new) ) delete_post_meta($post_id, $meta);
			  // Otherwise, update the current meta
			  else update_post_meta($post_id, $meta, $new);
		  }
	  }
	  	  
	  function activate() {
		// One time flush of rewrite rules
		flush_rewrite_rules();
	  }
	  
  }
}

function promoslider_display_image($values){
  global $post;
  extract($values);
  if( $image ): ?>
    <div class="promo_slider_background_image"><?php
      if( !get_post_meta($post->ID, '_promo_slider_disable_links', TRUE) ) echo '<a href="'.$destination_url.'" target="'.$target.'">';
	  echo $image;
	  if( !get_post_meta($post->ID, '_promo_slider_disable_links', TRUE) ) echo '</a>'; ?>
    </div><?php
  endif;
}
// Add action to display image
add_action('promoslider_content', 'promoslider_display_image');

function promoslider_display_title($values){
  global $post;
  extract($values);
  if( $title ): ?>
    <div class="promo_slider_title<?php if( !get_option('disable_fancy_title') ) echo ' fancy_ps_title'; ?>"><?php
	  if( !get_post_meta($post->ID, '_promo_slider_disable_links', TRUE) ) echo '<a href="'.$destination_url.'" target="'.$target.'">';
	  echo $title;
	  if( !get_post_meta($post->ID, '_promo_slider_disable_links', TRUE) ) echo '</a>'; ?>
    </div><?php
  endif;
}
// Add action to display title
if( get_option('show_title') ) add_action('promoslider_content', 'promoslider_display_title');

function promoslider_display_excerpt($values){
  extract($values);
  if($excerpt): ?>
    <div class="promo_slider_excerpt"><?php echo $excerpt; ?></div><?php
  endif;
}
// Add action to display excerpt
if( get_option('show_excerpt') ) add_action('promoslider_content', 'promoslider_display_excerpt');

function promoslider_display_nav(){ ?>
  <div class="promo_slider_nav<?php if(!get_option('disable_fancy_nav')) echo ' fancy_ps_nav'; ?>">
	<span class="move_backward pointer" title="Move Backward">&lt;&lt;</span>
	<span class="slider_selections pointer"></span>
	<span class="move_forward pointer" title="Move Forward">&gt;&gt;</span>
  </div><?php
}
// Add action to display nav
if( !get_option('nav_option') || get_option('nav_option') == 'default' ) add_action('promoslider_nav', 'promoslider_display_nav');

function promoslider_display_links(){ ?> 
  <div class="promo_slider_forward_link move_forward pointer" title="Move Forward"></div>
  <div class="promo_slider_backward_link move_backward pointer" title="Move Backward"></div><?php 
}
if( get_option('nav_option') == 'links' ) add_action('promoslider_nav', 'promoslider_display_links');

global $promo_slider;
$promo_slider = new promo_slider();

?>